Struct toad_string::FromUtf16Error
source · pub struct FromUtf16Error;Trait Implementations
sourceimpl Clone for FromUtf16Error
impl Clone for FromUtf16Error
sourcefn clone(&self) -> FromUtf16Error
fn clone(&self) -> FromUtf16Error
Returns a copy of the value. Read more
1.0.0 · sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moresourceimpl Debug for FromUtf16Error
impl Debug for FromUtf16Error
sourceimpl Default for FromUtf16Error
impl Default for FromUtf16Error
sourcefn default() -> FromUtf16Error
fn default() -> FromUtf16Error
Returns the “default value” for a type. Read more
sourceimpl Hash for FromUtf16Error
impl Hash for FromUtf16Error
sourceimpl Ord for FromUtf16Error
impl Ord for FromUtf16Error
sourcefn cmp(&self, other: &FromUtf16Error) -> Ordering
fn cmp(&self, other: &FromUtf16Error) -> Ordering
1.21.0 · sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere Self: Sized,
Compares and returns the maximum of two values. Read more
sourceimpl PartialEq<FromUtf16Error> for FromUtf16Error
impl PartialEq<FromUtf16Error> for FromUtf16Error
sourcefn eq(&self, other: &FromUtf16Error) -> bool
fn eq(&self, other: &FromUtf16Error) -> bool
This method tests for
self and other values to be equal, and is used
by ==.sourceimpl PartialOrd<FromUtf16Error> for FromUtf16Error
impl PartialOrd<FromUtf16Error> for FromUtf16Error
sourcefn partial_cmp(&self, other: &FromUtf16Error) -> Option<Ordering>
fn partial_cmp(&self, other: &FromUtf16Error) -> Option<Ordering>
1.0.0 · sourcefn le(&self, other: &Rhs) -> bool
fn le(&self, other: &Rhs) -> bool
This method tests less than or equal to (for
self and other) and is used by the <=
operator. Read moreimpl Copy for FromUtf16Error
impl Eq for FromUtf16Error
impl StructuralEq for FromUtf16Error
impl StructuralPartialEq for FromUtf16Error