Struct toad_string::FromUtf8Error
source · pub struct FromUtf8Error;Trait Implementations
sourceimpl Clone for FromUtf8Error
impl Clone for FromUtf8Error
sourcefn clone(&self) -> FromUtf8Error
fn clone(&self) -> FromUtf8Error
Returns a copy of the value. Read more
1.0.0 · sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moresourceimpl Debug for FromUtf8Error
impl Debug for FromUtf8Error
sourceimpl Default for FromUtf8Error
impl Default for FromUtf8Error
sourcefn default() -> FromUtf8Error
fn default() -> FromUtf8Error
Returns the “default value” for a type. Read more
sourceimpl Hash for FromUtf8Error
impl Hash for FromUtf8Error
sourceimpl Ord for FromUtf8Error
impl Ord for FromUtf8Error
sourcefn cmp(&self, other: &FromUtf8Error) -> Ordering
fn cmp(&self, other: &FromUtf8Error) -> Ordering
1.21.0 · sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere Self: Sized,
Compares and returns the maximum of two values. Read more
sourceimpl PartialEq<FromUtf8Error> for FromUtf8Error
impl PartialEq<FromUtf8Error> for FromUtf8Error
sourcefn eq(&self, other: &FromUtf8Error) -> bool
fn eq(&self, other: &FromUtf8Error) -> bool
This method tests for
self and other values to be equal, and is used
by ==.sourceimpl PartialOrd<FromUtf8Error> for FromUtf8Error
impl PartialOrd<FromUtf8Error> for FromUtf8Error
sourcefn partial_cmp(&self, other: &FromUtf8Error) -> Option<Ordering>
fn partial_cmp(&self, other: &FromUtf8Error) -> Option<Ordering>
1.0.0 · sourcefn le(&self, other: &Rhs) -> bool
fn le(&self, other: &Rhs) -> bool
This method tests less than or equal to (for
self and other) and is used by the <=
operator. Read moreimpl Copy for FromUtf8Error
impl Eq for FromUtf8Error
impl StructuralEq for FromUtf8Error
impl StructuralPartialEq for FromUtf8Error